'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.CTCMercuryStyleTemplates = exports.languagePickerTemplates = exports.modalStyleTemplates = exports.switchStyleTemplates = exports.buttonStyles = exports.cardStyles = undefined;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _helperFunctions = require('./helperFunctions');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var cardStyles = exports.cardStyles = {
  none: {
    baseContainerStyle: {},
    baseImageStyle: {
      backgroundRepeat: 'no-repeat',
      backgroundPosition: 'center',
      backgroundSize: 'contain'
    },
    baseSternStyle: {},
    baseStarboardStyle: {},
    baseTitleStyle: {},
    baseSubtitleStyle: {}
  },
  neutral: {
    baseContainerStyle: {
      backgroundColor: 'rgba(255, 255, 255, 0.8)',
      position: 'relative',
      padding: '0.5rem 1rem',
      marginLeft: '1rem',
      minWidth: '16rem'
    },
    baseImageStyle: {
      overflow: 'hidden',
      backgroundPosition: 'center', //justifyContent: 'center', //alignItems: `center`,
      marginBottom: '8px',
      borderRadius: '3px 3px 0',
      display: 'flex',
      backgroundRepeat: 'no-repeat',
      backgroundSize: 'contain',
      height: '19rem'
    },
    baseSternStyle: {},
    baseStarboardStyle: {},
    baseTitleStyle: { textAlign: 'center', padding: '5px' },
    baseSubtitleStyle: { textAlign: 'center', padding: '5px' }
  }
};
var buttonStyles = exports.buttonStyles = {
  vivid: {
    transition: 'smooth',
    on: { backgroundColor: '#33aaff', color: '#eeeeee' },
    off: { backgroundColor: '#ffbb33', color: '#333333' },
    diff: 10
  },
  neutral: {
    transition: 'mix',
    on: { backgroundColor: '#dddddd' },
    off: { backgroundColor: '#ffffff' },
    disabled: { backgroundColor: '#ccc', color: '#888' },
    diff: 30
  },
  transparentNeutral: {
    transition: 'mix',
    on: { backgroundColor: '#aaa9' },
    off: { backgroundColor: '#0000' },
    disabled: { backgroundColor: '#ccc', color: '#888' },
    diff: 30
  },
  link: { on: { color: '#999' }, off: { color: '#111' }, transition: 'text', diff: 40 },
  vampire: {
    on: { backgroundColor: '#bb2222', color: '#eeeeee' },
    off: { backgroundColor: '#e4e4e4', color: '#333333' },
    diff: 20,
    transition: 'mix'
  },
  facebook: {
    off: { backgroundColor: '#4267b2', color: '#eeeeee' },
    on: { backgroundColor: '#e4e4e4', color: '#333333' },
    diff: 5,
    transition: 'smooth'
  },
  google: {
    off: { backgroundColor: '#fff', color: '#5f646d' },
    on: { backgroundColor: '#e4e4e4', color: '#333333' },
    diff: 5,
    transition: 'smooth'
  },
  redden: {
    on: { backgroundColor: '#ff8888', color: '#eeeeee' },
    off: { backgroundColor: '#0000', color: '#333333' },
    diff: 25,
    transition: 'mix'
  },
  verdant: {
    on: { backgroundColor: '#66bb66', color: '#fff' },
    off: { backgroundColor: '#0000', color: '#333333' },
    diff: 20,
    transition: 'mix'
  },
  traffic: {
    on: { backgroundColor: '#dd3333', color: '#eeeeee' },
    off: { backgroundColor: '#33dd33', color: '#333333' },
    diff: 20,
    transition: 'contrast'
  },
  delphinium: {
    on: { backgroundColor: '#dd33dd88', color: '#111' },
    off: { backgroundColor: '#ffffff', color: '#111' },
    diff: 25,
    transition: 'mix'
  },
  lisanthus: {
    on: { backgroundColor: '#591b64', color: '#eee' },
    off: { backgroundColor: '#ffffff', color: '#414' },
    diff: 25,
    transition: 'mix'
  },
  darken: {
    on: { backgroundColor: '#0009', color: '#fff' },
    off: { backgroundColor: '#0000', color: '#111' },
    diff: 20,
    transition: 'mix'
  },
  monochrome: {
    on: { backgroundColor: '#333333', color: '#f4f4f4' },
    off: { backgroundColor: '#fafafa', color: '#333333' },
    diff: 20,
    transition: 'mix'
  },
  surfing: {
    on: { backgroundColor: '#003b46', color: '#eeffff' },
    off: { backgroundColor: '#c4dfe6', color: '#001924' },
    diff: 10,
    transition: 'mix'
  }
};
var switchStyleTemplates = exports.switchStyleTemplates = {
  default: {
    option: {
      cursor: 'pointer'
    },
    content: {
      transition: 'all 150ms ease-in-out'
    }
  }
};

var modalStyleTemplates = exports.modalStyleTemplates = {
  basic: {
    container: {
      position: 'relative',
      cursor: 'default',
      background: '#fff'
    },
    getBody: function getBody() {
      return {};
    },
    body: {
      opacity: 1
    },
    background: {
      zIndex: 2,
      background: '#000a',
      position: 'fixed',
      height: '100%',
      top: '0',
      left: '0',
      width: '100%',
      display: 'flex',
      alignItems: 'center',
      justifyContent: 'center'
    },
    header: {},
    buttons: {},
    closemodalbutton: {
      zIndex: 1,
      cursor: 'pointer',
      position: 'absolute'
    }
  },
  default: {
    container: {
      position: 'relative',

      cursor: 'default',

      margin: '0 1rem',
      opacity: '1',
      color: '#020202',
      background: 'red',
      border: '1px solid #575757',
      zIndex: '0',
      borderRadius: '0.375rem'
    },
    getBody: function getBody(_ref) {
      var hasHeader = _ref.hasHeader,
          hasFooter = _ref.hasFooter;
      return console.log(hasHeader, hasFooter) || {
        background: '#fdfdfd',
        padding: '2.4rem 1.2rem',
        overflowY: 'auto',
        borderRadius: (hasHeader ? '0 0' : '0.375rem 0.375rem') + ' ' + (hasFooter ? '0 0' : '0.375rem 0.375rem')
      };
    },
    body: {
      background: '#fdfdfd',
      padding: '2.4rem 1.2rem',
      overflowY: 'auto'
    },
    background: {
      position: 'fixed',
      height: '100%',
      top: '0',
      left: '0',
      width: '100%',
      background: 'rgba(0, 0, 0, 0.5)',
      zIndex: '2',
      display: 'flex',
      alignItems: 'center',
      justifyContent: 'center',
      WebkitTapHighlightColor: 'transparent'
    },
    header: {
      margin: '0',
      padding: '2rem 2rem 1.5rem 2rem',
      borderBottom: '0.5rem solid #f0f0f0',
      borderRadius: '0.375rem 0.375rem 0 0 ',
      background: '#fafafa'
    },
    buttons: {
      borderTop: '1px solid #575757',
      borderRadius: '0 0 0.375rem 0.375rem  ',
      padding: '0.5rem',
      background: '#fafafa',
      display: 'flex',
      alignItems: 'center',
      justifyContent: 'flex-end'
    },
    closemodalbutton: {
      zIndex: 2,
      top: '0.5rem',
      right: '0.5rem',
      cursor: 'pointer',
      position: 'absolute',
      background: '#fff',
      borderRadius: '100%',
      display: 'flex'
    }
  }
};
var languagePickerTemplates = exports.languagePickerTemplates = {
  none: {
    children: {
      position: 'absolute'
    },
    item: {},
    trigger: {}
  },
  default: {
    children: {
      position: 'absolute'
    },
    item: {
      width: '2.5rem',
      height: '2rem',
      backgroundRepeat: 'no-repeat',
      backgroundPosition: 'center',
      backgroundSize: '80%'
    },
    trigger: {
      width: '2.5rem',
      height: '2rem',
      backgroundRepeat: 'no-repeat',
      backgroundPosition: 'center',
      backgroundSize: '80%'
    }
  }
};

var CTCMercuryStyleTemplates = exports.CTCMercuryStyleTemplates = {
  default: {
    buttonColors: buttonStyles.neutral,
    getBarStyle: function getBarStyle(isOn) {
      return {
        transition: 'flex-grow 0.5s linear',
        padding: '0.25rem 0'
      };
    },
    getSideBarStyle: function getSideBarStyle(isOn) {
      return {
        flexGrow: isOn ? 0.5 : 1,
        backgroundColor: '#111',
        height: '1rem'
      };
    },
    getLeftBarStyle: function getLeftBarStyle(isOn) {
      return {};
    },
    getRightBarStyle: function getRightBarStyle(isOn) {
      return {};
    },
    getCenterBarStyle: function getCenterBarStyle(isOn) {
      return {
        flexGrow: isOn ? 1 : 0.5
      };
    }
  },
  weird: {
    buttonColors: buttonStyles.vivid,
    getBarStyle: function getBarStyle(isOn) {
      return {
        transition: 'flex-grow 0.5s linear',
        padding: '0.25rem 0'
      };
    },
    getSideBarStyle: function getSideBarStyle(isOn) {
      return {
        flexGrow: isOn ? 0.2 : 1,
        backgroundColor: isOn ? '#3c3' : '#464',
        height: '0.5rem'
      };
    },
    getLeftBarStyle: function getLeftBarStyle(isOn) {
      return {};
    },
    getRightBarStyle: function getRightBarStyle(isOn) {
      return {};
    },
    getCenterBarStyle: function getCenterBarStyle(isOn) {
      return {
        flexGrow: isOn ? 1 : 0.2,
        backgroundColor: '#000',
        color: '#fff'
      };
    }
  }
};